@@ -1,25 +1,25 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
- 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #include "hscroll.h"
 #include "charset.h"
-#include "glib_compat.h"
+#include "ncfix.h"
 
 #include <assert.h>
 #include <string.h>
@@ -28,21 +28,18 @@ char *
 strscroll(struct hscroll *hscroll, const char *str, const char *separator,
 	  unsigned width)
 {
-	gchar *tmp, *buf;
-
 	assert(hscroll != NULL);
 	assert(str != NULL);
 	assert(separator != NULL);
 
 	/* create a buffer containing the string and the separator */
-	tmp = replace_locale_to_utf8(g_strconcat(str, separator,
-						 str, separator, NULL));
-
+	char *tmp = replace_locale_to_utf8(g_strconcat(str, separator,
+						       str, separator, NULL));
 	if (hscroll->offset >= (unsigned)g_utf8_strlen(tmp, -1) / 2)
 		hscroll->offset = 0;
 
 	/* create the new scrolled string */
-	buf = g_utf8_offset_to_pointer(tmp, hscroll->offset);
+	char *buf = g_utf8_offset_to_pointer(tmp, hscroll->offset);
 	utf8_cut_width(buf, width);
 
 	/* convert back to locale */
@@ -87,7 +84,7 @@ hscroll_set(struct hscroll *hscroll, unsigned x, unsigned y, unsigned width,
 
 	/* obtain the ncurses attributes and the current color, store
 	   them */
-	wattr_get(hscroll->w, &hscroll->attrs, &hscroll->pair, NULL);
+	fix_wattr_get(hscroll->w, &hscroll->attrs, &hscroll->pair, NULL);
 
 	hscroll->text = g_strdup(text);
 	hscroll->offset = 0;
@@ -112,21 +109,19 @@ hscroll_clear(struct hscroll *hscroll)
 void
 hscroll_draw(struct hscroll *hscroll)
 {
-	attr_t old_attrs;
-	short old_pair;
-	char *p;
-
 	assert(hscroll != NULL);
 	assert(hscroll->w != NULL);
 	assert(hscroll->text != NULL);
 
 	/* set stored attributes and color */
-	wattr_get(hscroll->w, &old_attrs, &old_pair, NULL);
+	attr_t old_attrs;
+	short old_pair;
+	fix_wattr_get(hscroll->w, &old_attrs, &old_pair, NULL);
 	wattr_set(hscroll->w, hscroll->attrs, hscroll->pair, NULL);
 
 	/* scroll the string, and draw it */
-	p = strscroll(hscroll, hscroll->text, hscroll->separator,
-		      hscroll->width);
+	char *p = strscroll(hscroll, hscroll->text, hscroll->separator,
+			    hscroll->width);
 	mvwaddstr(hscroll->w, hscroll->y, hscroll->x, p);
 	g_free(p);
 
