@@ -1,25 +1,27 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
- 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
-#include <lirc/lirc_client.h>
 #include "lirc.h"
 #include "ncmpc.h"
+#include "Compiler.h"
+
+#include <lirc/lirc_client.h>
 
 static struct lirc_config *lc = NULL;
 
@@ -47,8 +49,8 @@ void ncmpc_lirc_close()
 }
 
 gboolean
-lirc_event(G_GNUC_UNUSED GIOChannel *source,
-	   G_GNUC_UNUSED GIOCondition condition, G_GNUC_UNUSED gpointer data)
+lirc_event(gcc_unused GIOChannel *source,
+	   gcc_unused GIOCondition condition, gcc_unused gpointer data)
 {
 	char *code, *txt;
 	command_t cmd;
