@@ -1,21 +1,21 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
- 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #include "playlist.h"
 
@@ -31,11 +31,9 @@ playlist_init(struct mpdclient_playlist *playlist)
 void
 playlist_clear(struct mpdclient_playlist *playlist)
 {
-	guint i;
-
 	playlist->version = 0;
 
-	for (i = 0; i < playlist->list->len; ++i) {
+	for (unsigned i = 0; i < playlist->list->len; ++i) {
 		struct mpd_song *song = playlist_get(playlist, i);
 
 		mpd_song_free(song);
@@ -69,14 +67,12 @@ void
 playlist_move(struct mpdclient_playlist *playlist,
 	      unsigned dest, unsigned src)
 {
-	struct mpd_song *song;
-
 	assert(playlist != NULL);
 	assert(src < playlist_length(playlist));
 	assert(dest < playlist_length(playlist));
 	assert(src != dest);
 
-	song = playlist_get(playlist, src);
+	struct mpd_song *song = playlist_get(playlist, src);
 
 	if (src < dest) {
 		memmove(&playlist->list->pdata[src],
