@@ -1,25 +1,27 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
- 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #ifndef MPDCLIENT_PLAYLIST_H
 #define MPDCLIENT_PLAYLIST_H
 
+#include "Compiler.h"
+
 #include <mpd/client.h>
 
 #include <assert.h>
@@ -131,10 +133,12 @@ playlist_get_index_from_same_song(const struct mpdclient_playlist *playlist,
 	return playlist_get_index_from_file(playlist, mpd_song_get_uri(song));
 }
 
+gcc_pure
 gint
 playlist_get_id_from_uri(const struct mpdclient_playlist *playlist,
 			 const gchar *uri);
 
+gcc_pure
 static inline gint
 playlist_get_id_from_same_song(const struct mpdclient_playlist *playlist,
 			       const struct mpd_song *song)
