@@ -1,21 +1,21 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
- 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #ifndef PLUGIN_H
 #define PLUGIN_H
@@ -38,10 +38,12 @@ struct plugin_list {
  * messages on failure as determined by success
  * @param success result of the plugin cycle; true if result is meaningful
  * output, false if result contains error messages
+ * @param plugin_name the name of the plugin which succeeded; becomes invalid
+ * when plugin_stop is called (i.e. strdup it if you need it afterwards).
  * @param data the caller defined pointer passed to plugin_run()
  */
 typedef void (*plugin_callback_t)(const GString *result, const bool success,
-				  void *data);
+				  const char *plugin_name, void *data);
 
 /**
  * This object represents a cycle through all available plugins, until
