@@ -1,25 +1,25 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
-
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #include "screen_artist.h"
 #include "screen_interface.h"
-#include "screen_message.h"
+#include "screen_status.h"
 #include "screen_find.h"
 #include "screen_browser.h"
 #include "screen.h"
@@ -28,6 +28,7 @@
 #include "mpdclient.h"
 #include "screen_browser.h"
 #include "filelist.h"
+#include "options.h"
 
 #include <assert.h>
 #include <string.h>
@@ -41,6 +42,7 @@ static artist_mode_t mode = LIST_ARTISTS;
 static GPtrArray *artist_list, *album_list;
 static char *artist = NULL;
 static char *album  = NULL;
+static char ALL_TRACKS[] = "";
 
 static struct screen_browser browser;
 
@@ -48,12 +50,10 @@ static gint
 compare_utf8(gconstpointer s1, gconstpointer s2)
 {
 	const char *const*t1 = s1, *const*t2 = s2;
-	char *key1, *key2;
-	int n;
 
-	key1 = g_utf8_collate_key(*t1,-1);
-	key2 = g_utf8_collate_key(*t2,-1);
-	n = strcmp(key1,key2);
+	char *key1 = g_utf8_collate_key(*t1,-1);
+	char *key2 = g_utf8_collate_key(*t2,-1);
+	int n = strcmp(key1,key2);
 	g_free(key1);
 	g_free(key2);
 	return n;
@@ -64,8 +64,6 @@ static const char *
 screen_artist_lw_callback(unsigned idx, void *data)
 {
 	GPtrArray *list = data;
-	static char buf[BUFSIZE];
-	char *str, *str_utf8;
 
 	if (mode == LIST_ALBUMS) {
 		if (idx == 0)
@@ -78,10 +76,12 @@ screen_artist_lw_callback(unsigned idx, void *data)
 
 	assert(idx < list->len);
 
-	str_utf8 = g_ptr_array_index(list, idx);
+	char *str_utf8 = g_ptr_array_index(list, idx);
 	assert(str_utf8 != NULL);
 
-	str = utf8_to_locale(str_utf8);
+	char *str = utf8_to_locale(str_utf8);
+
+	static char buf[BUFSIZE];
 	g_strlcpy(buf, str, sizeof(buf));
 	g_free(str);
 
@@ -101,9 +101,7 @@ artist_repaint(void)
 static void
 string_array_free(GPtrArray *array)
 {
-	unsigned i;
-
-	for (i = 0; i < array->len; ++i) {
+	for (unsigned i = 0; i < array->len; ++i) {
 		char *value = g_ptr_array_index(array, i);
 		g_free(value);
 	}
@@ -161,8 +159,7 @@ load_artist_list(struct mpdclient *c)
 		mpd_search_commit(connection);
 		recv_tag_values(connection, MPD_TAG_ARTIST, artist_list);
 
-		if (!mpd_response_finish(connection))
-			mpdclient_handle_error(c);
+		mpdclient_finish_command(c);
 	}
 
 	/* sort list */
@@ -192,8 +189,7 @@ load_album_list(struct mpdclient *c)
 
 		recv_tag_values(connection, MPD_TAG_ALBUM, album_list);
 
-		if (!mpd_response_finish(connection))
-			mpdclient_handle_error(c);
+		mpdclient_finish_command(c);
 	}
 
 	/* sort list */
@@ -220,15 +216,14 @@ load_song_list(struct mpdclient *c)
 		mpd_search_db_songs(connection, true);
 		mpd_search_add_tag_constraint(connection, MPD_OPERATOR_DEFAULT,
 					      MPD_TAG_ARTIST, artist);
-		if (album[0] != 0)
+		if (album != ALL_TRACKS)
 			mpd_search_add_tag_constraint(connection, MPD_OPERATOR_DEFAULT,
 						      MPD_TAG_ALBUM, album);
 		mpd_search_commit(connection);
 
 		filelist_recv(browser.filelist, connection);
 
-		if (!mpd_response_finish(connection))
-			mpdclient_handle_error(c);
+		mpdclient_finish_command(c);
 	}
 
 	/* fix highlights */
@@ -240,7 +235,8 @@ static void
 free_state(void)
 {
 	g_free(artist);
-	g_free(album);
+	if (album != ALL_TRACKS)
+		g_free(album);
 	artist = NULL;
 	album = NULL;
 
@@ -306,6 +302,7 @@ static void
 screen_artist_init(WINDOW *w, int cols, int rows)
 {
 	browser.lw = list_window_init(w, cols, rows);
+	browser.song_format = options.list_format;
 	artist = NULL;
 	album = NULL;
 }
@@ -336,10 +333,10 @@ screen_artist_resize(int cols, int rows)
  */
 static void
 paint_artist_callback(WINDOW *w, unsigned i,
-		      G_GNUC_UNUSED unsigned y, unsigned width,
-		      bool selected, void *data)
+		      gcc_unused unsigned y, unsigned width,
+		      bool selected, const void *data)
 {
-	GPtrArray *list = data;
+	const GPtrArray *list = data;
 	char *p = utf8_to_locale(g_ptr_array_index(list, i));
 
 	screen_browser_paint_directory(w, width, selected, p);
@@ -354,10 +351,10 @@ paint_artist_callback(WINDOW *w, unsigned i,
  */
 static void
 paint_album_callback(WINDOW *w, unsigned i,
-		     G_GNUC_UNUSED unsigned y, unsigned width,
-		     bool selected, void *data)
+		     gcc_unused unsigned y, unsigned width,
+		     bool selected, const void *data)
 {
-	GPtrArray *list = data;
+	const GPtrArray *list = data;
 	const char *p;
 	char *q = NULL;
 
@@ -392,9 +389,9 @@ screen_artist_paint(void)
 static const char *
 screen_artist_get_title(char *str, size_t size)
 {
-	char *s1, *s2;
-
 	switch(mode) {
+		char *s1, *s2;
+
 	case LIST_ARTISTS:
 		g_snprintf(str, size, _("All artists"));
 		break;
@@ -407,14 +404,17 @@ screen_artist_get_title(char *str, size_t size)
 
 	case LIST_SONGS:
 		s1 = utf8_to_locale(artist);
-		if (*album != 0) {
-			s2 = utf8_to_locale(album);
+
+		if (album == ALL_TRACKS)
 			g_snprintf(str, size,
-				   _("Album: %s - %s"), s1, s2);
+				   _("All tracks of artist: %s"), s1);
+		else if (*album != 0) {
+			s2 = utf8_to_locale(album);
+			g_snprintf(str, size, _("Album: %s - %s"), s1, s2);
 			g_free(s2);
 		} else
 			g_snprintf(str, size,
-				   _("All tracks of artist: %s"), s1);
+				   _("Tracks of no album of artist: %s"), s1);
 		g_free(s1);
 		break;
 	}
@@ -443,36 +443,39 @@ screen_artist_update(struct mpdclient *c)
 		artist_repaint();
 }
 
+/* add_query - Add all songs satisfying specified criteria.
+   _artist is actually only used in the ALBUM case to distinguish albums with
+   the same name from different artists. */
 static void
-add_query(struct mpdclient *c, enum mpd_tag_type table, char *_filter)
+add_query(struct mpdclient *c, enum mpd_tag_type table, const char *_filter,
+	  const char *_artist)
 {
 	struct mpd_connection *connection = mpdclient_get_connection(c);
-	char *str;
-	struct filelist *addlist;
 
-	assert(filter != NULL);
+	assert(_filter != NULL);
 
 	if (connection == NULL)
 		return;
 
-	str = utf8_to_locale(_filter);
+	char *str = utf8_to_locale(_filter);
 	if (table == MPD_TAG_ALBUM)
-		screen_status_printf("Adding album %s...", str);
+		screen_status_printf(_("Adding album %s..."), str);
 	else
-		screen_status_printf("Adding %s...", str);
+		screen_status_printf(_("Adding %s..."), str);
 	g_free(str);
 
 	mpd_search_db_songs(connection, true);
 	mpd_search_add_tag_constraint(connection, MPD_OPERATOR_DEFAULT,
 				      table, _filter);
+	if (table == MPD_TAG_ALBUM)
+		mpd_search_add_tag_constraint(connection, MPD_OPERATOR_DEFAULT,
+					      MPD_TAG_ARTIST, _artist);
 	mpd_search_commit(connection);
 
-	addlist = filelist_new_recv(connection);
+	struct filelist *addlist = filelist_new_recv(connection);
 
-	if (mpd_response_finish(connection))
+	if (mpdclient_finish_command(c))
 		mpdclient_filelist_add_all(c, addlist);
-	else
-		mpdclient_handle_error(c);
 
 	filelist_free(addlist);
 }
@@ -509,12 +512,13 @@ string_array_find(GPtrArray *array, const char *value)
 static bool
 screen_artist_cmd(struct mpdclient *c, command_t cmd)
 {
-	struct list_window_range range;
-	char *selected;
-	char *old;
-	int idx;
-
 	switch(cmd) {
+		struct list_window_range range;
+		char *selected;
+		char *old;
+		char *old_ptr;
+		int idx;
+
 	case CMD_PLAY:
 		switch (mode) {
 		case LIST_ARTISTS:
@@ -546,7 +550,7 @@ screen_artist_cmd(struct mpdclient *c, command_t cmd)
 				}
 			} else if (browser.lw->selected == album_list->len + 1) {
 				/* handle "show all" */
-				open_song_list(c, g_strdup(artist), g_strdup("\0"));
+				open_song_list(c, g_strdup(artist), ALL_TRACKS);
 				list_window_reset(browser.lw);
 			} else {
 				/* select album */
@@ -563,11 +567,12 @@ screen_artist_cmd(struct mpdclient *c, command_t cmd)
 			if (browser.lw->selected == 0) {
 				/* handle ".." */
 				old = g_strdup(album);
+				old_ptr = album;
 
 				open_album_list(c, g_strdup(artist));
 				list_window_reset(browser.lw);
 				/* restore previous list window state */
-				idx = *old == 0
+				idx = old_ptr == ALL_TRACKS
 					? (int)album_list->len
 					: string_array_find(album_list, old);
 				g_free(old);
@@ -609,11 +614,12 @@ screen_artist_cmd(struct mpdclient *c, command_t cmd)
 
 		case LIST_SONGS:
 			old = g_strdup(album);
+			old_ptr = album;
 
 			open_album_list(c, g_strdup(artist));
 			list_window_reset(browser.lw);
 			/* restore previous list window state */
-			idx = *old == 0
+			idx = old_ptr == ALL_TRACKS
 				? (int)album_list->len
 				: string_array_find(album_list, old);
 			g_free(old);
@@ -656,7 +662,7 @@ screen_artist_cmd(struct mpdclient *c, command_t cmd)
 			list_window_get_range(browser.lw, &range);
 			for (unsigned i = range.start; i < range.end; ++i) {
 				selected = g_ptr_array_index(artist_list, i);
-				add_query(c, MPD_TAG_ARTIST, selected);
+				add_query(c, MPD_TAG_ARTIST, selected, NULL);
 				cmd = CMD_LIST_NEXT; /* continue and select next item... */
 			}
 			break;
@@ -665,12 +671,12 @@ screen_artist_cmd(struct mpdclient *c, command_t cmd)
 			list_window_get_range(browser.lw, &range);
 			for (unsigned i = range.start; i < range.end; ++i) {
 				if(i == album_list->len + 1)
-					add_query(c, MPD_TAG_ARTIST, artist);
+					add_query(c, MPD_TAG_ARTIST, artist, NULL);
 				else if (i > 0)
 				{
 					selected = g_ptr_array_index(album_list,
 								     browser.lw->selected - 1);
-					add_query(c, MPD_TAG_ALBUM, selected);
+					add_query(c, MPD_TAG_ALBUM, selected, artist);
 					cmd = CMD_LIST_NEXT; /* continue and select next item... */
 				}
 			}
@@ -711,13 +717,15 @@ screen_artist_cmd(struct mpdclient *c, command_t cmd)
 	case CMD_LIST_JUMP:
 		switch (mode) {
 		case LIST_ARTISTS:
-			screen_jump(browser.lw, screen_artist_lw_callback,
+			screen_jump(browser.lw,
+				    screen_artist_lw_callback, artist_list,
 				    paint_artist_callback, artist_list);
 			artist_repaint();
 			return true;
 
 		case LIST_ALBUMS:
-			screen_jump(browser.lw, screen_artist_lw_callback,
+			screen_jump(browser.lw,
+				    screen_artist_lw_callback, album_list,
 				    paint_album_callback, album_list);
 			artist_repaint();
 			return true;
