@@ -1,21 +1,21 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
-
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #include "screen_help.h"
 #include "screen_interface.h"
@@ -72,6 +72,9 @@ static const struct help_text_row help_text[] = {
 #ifdef ENABLE_OUTPUTS_SCREEN
 	{ 0, CMD_SCREEN_OUTPUTS, NULL },
 #endif
+#ifdef ENABLE_CHAT_SCREEN
+	{ 0, CMD_SCREEN_CHAT, NULL },
+#endif
 #ifdef ENABLE_KEYDEF_SCREEN
 	{ 0, CMD_SCREEN_KEYDEF, NULL },
 #endif
@@ -105,13 +108,15 @@ static const struct help_text_row help_text[] = {
 	{ 0, CMD_LIST_JUMP, NULL },
 	{ 0, CMD_TOGGLE_FIND_WRAP, NULL },
 	{ 0, CMD_LOCATE, NULL },
+#ifdef ENABLE_SONG_SCREEN
 	{ 0, CMD_SCREEN_SONG, NULL },
+#endif
 	{ 0, CMD_NONE, NULL },
 	{ 0, CMD_QUIT, NULL },
 
 	{ 0, CMD_NONE, NULL },
 	{ 0, CMD_NONE, NULL },
-	{ 1, CMD_NONE, N_("Playlist screen") },
+	{ 1, CMD_NONE, N_("Queue screen") },
 	{ 2, CMD_NONE, NULL },
 	{ 0, CMD_PLAY, N_("Play") },
 	{ 0, CMD_DELETE, NULL },
@@ -130,7 +135,7 @@ static const struct help_text_row help_text[] = {
 	{ 2, CMD_NONE, NULL },
 	{ 0, CMD_PLAY, N_("Enter directory/Select and play song") },
 	{ 0, CMD_SELECT, NULL },
-	{ 0, CMD_ADD, N_("Append song to playlist") },
+	{ 0, CMD_ADD, N_("Append song to queue") },
 	{ 0, CMD_SAVE_PLAYLIST, NULL },
 	{ 0, CMD_DELETE, N_("Delete playlist") },
 	{ 0, CMD_GO_PARENT_DIRECTORY, NULL },
@@ -145,7 +150,7 @@ static const struct help_text_row help_text[] = {
 	{ 0, CMD_SCREEN_SEARCH, N_("Search") },
 	{ 0, CMD_PLAY, N_("Select and play") },
 	{ 0, CMD_SELECT, NULL },
-	{ 0, CMD_ADD, N_("Append song to playlist") },
+	{ 0, CMD_ADD, N_("Append song to queue") },
 	{ 0, CMD_SELECT_ALL,	 NULL },
 	{ 0, CMD_SEARCH_MODE, NULL },
 #endif
@@ -160,6 +165,7 @@ static const struct help_text_row help_text[] = {
 	   from the server */
 	{ 0, CMD_INTERRUPT, N_("Interrupt retrieval") },
 	{ 0, CMD_LYRICS_UPDATE, N_("Download lyrics for currently playing song") },
+	{ 0, CMD_EDIT, N_("Add or edit lyrics") },
 	{ 0, CMD_SAVE_PLAYLIST, N_("Save lyrics") },
 	{ 0, CMD_DELETE, N_("Delete saved lyrics") },
 #endif
@@ -170,6 +176,13 @@ static const struct help_text_row help_text[] = {
 	{ 2, CMD_NONE, NULL },
 	{ 0, CMD_PLAY, N_("Enable/disable output") },
 #endif
+#ifdef ENABLE_CHAT_SCREEN
+	{ 0, CMD_NONE, NULL },
+	{ 0, CMD_NONE, NULL },
+	{ 1, CMD_NONE, N_("Chat screen") },
+	{ 2, CMD_NONE, NULL },
+	{ 0, CMD_PLAY, N_("Write a message") },
+#endif
 #ifdef ENABLE_KEYDEF_SCREEN
 	{ 0, CMD_NONE, NULL },
 	{ 0, CMD_NONE, NULL },
@@ -177,6 +190,7 @@ static const struct help_text_row help_text[] = {
 	{ 2, CMD_NONE, NULL },
 	{ 0, CMD_PLAY, N_("Edit keydefs for selected command") },
 	{ 0, CMD_DELETE, N_("Remove selected keydef") },
+	{ 0, CMD_ADD, N_("Add a keydef") },
 	{ 0, CMD_GO_PARENT_DIRECTORY, N_("Go up a level") },
 	{ 0, CMD_SAVE_PLAYLIST, N_("Apply and save changes") },
 #endif
@@ -185,7 +199,7 @@ static const struct help_text_row help_text[] = {
 static struct list_window *lw;
 
 static const char *
-list_callback(unsigned i, G_GNUC_UNUSED void *data)
+list_callback(unsigned i, gcc_unused void *data)
 {
 	const struct help_text_row *row = &help_text[i];
 
@@ -222,7 +236,7 @@ help_exit(void)
 
 
 static const char *
-help_title(G_GNUC_UNUSED char *str, G_GNUC_UNUSED size_t size)
+help_title(gcc_unused char *str, gcc_unused size_t size)
 {
 	return _("Help");
 }
@@ -230,8 +244,8 @@ help_title(G_GNUC_UNUSED char *str, G_GNUC_UNUSED size_t size)
 static void
 screen_help_paint_callback(WINDOW *w, unsigned i,
 			   unsigned y, unsigned width,
-			   G_GNUC_UNUSED bool selected,
-			   G_GNUC_UNUSED void *data)
+			   gcc_unused bool selected,
+			   gcc_unused const void *data)
 {
 	const struct help_text_row *row = &help_text[i];
 
@@ -267,7 +281,7 @@ help_paint(void)
 }
 
 static bool
-help_cmd(G_GNUC_UNUSED struct mpdclient *c, command_t cmd)
+help_cmd(gcc_unused struct mpdclient *c, command_t cmd)
 {
 	if (list_window_scroll_cmd(lw, cmd)) {
 		help_paint();
