@@ -1,25 +1,25 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
-
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #include "screen_outputs.h"
 #include "screen_interface.h"
-#include "screen_message.h"
+#include "screen_status.h"
 #include "paint.h"
 #include "i18n.h"
 #include "list_window.h"
@@ -47,20 +47,17 @@ outputs_repaint(void)
 static bool
 toggle_output(struct mpdclient *c, unsigned int output_index)
 {
-	struct mpd_connection *connection;
-	struct mpd_output *output;
-
 	assert(mpd_outputs != NULL);
 
 	if (output_index >= mpd_outputs->len)
 		return false;
 
-	connection = mpdclient_get_connection(c);
+	struct mpd_connection *connection = mpdclient_get_connection(c);
 	if (connection == NULL)
 		return false;
 
-	output = g_ptr_array_index(mpd_outputs, output_index);
-
+	struct mpd_output *output =
+		g_ptr_array_index(mpd_outputs, output_index);
 	if (!mpd_output_get_enabled(output)) {
 		if (!mpd_run_enable_output(connection,
 					   mpd_output_get_id(output))) {
@@ -89,7 +86,7 @@ toggle_output(struct mpdclient *c, unsigned int output_index)
 }
 
 static void
-clear_output_element(gpointer data, G_GNUC_UNUSED gpointer user_data)
+clear_output_element(gpointer data, gcc_unused gpointer user_data)
 {
 	mpd_output_free(data);
 }
@@ -114,24 +111,22 @@ clear_outputs_list(void)
 static void
 fill_outputs_list(struct mpdclient *c)
 {
-	struct mpd_connection *connection;
-	struct mpd_output *output;
-
 	assert(mpd_outputs != NULL);
 
-	connection = mpdclient_get_connection(c);
+	struct mpd_connection *connection = mpdclient_get_connection(c);
 	if (connection == NULL) {
 		list_window_set_length(lw, 0);
 		return;
 	}
 
 	mpd_send_outputs(connection);
+
+	struct mpd_output *output;
 	while ((output = mpd_recv_output(connection)) != NULL) {
 		g_ptr_array_add(mpd_outputs, output);
 	}
 
-	if (!mpd_response_finish(connection))
-		mpdclient_handle_error(c);
+	mpdclient_finish_command(c);
 
 	list_window_set_length(lw, mpd_outputs->len);
 }
@@ -171,15 +166,15 @@ outputs_close(void)
 }
 
 static const char *
-outputs_title(G_GNUC_UNUSED char *str, G_GNUC_UNUSED size_t size)
+outputs_title(gcc_unused char *str, gcc_unused size_t size)
 {
 	return _("Outputs");
 }
 
 static void
 screen_outputs_paint_callback(WINDOW *w, unsigned i,
-			      G_GNUC_UNUSED unsigned y, unsigned width,
-			      bool selected, G_GNUC_UNUSED void *data)
+			      gcc_unused unsigned y, unsigned width,
+			      bool selected, gcc_unused const void *data)
 {
 	const struct mpd_output *output;
 
@@ -245,7 +240,7 @@ const struct screen_functions screen_outputs = {
 	.close     = outputs_close,
 	.resize    = outputs_resize,
 	.paint     = outputs_paint,
-	.update = screen_outputs_update,
+	.update    = screen_outputs_update,
 	.cmd       = outputs_cmd,
 	.get_title = outputs_title,
 };
