@@ -1,21 +1,21 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
-
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #include "screen_song.h"
 #include "screen_interface.h"
@@ -36,7 +36,10 @@
 
 enum {
 	LABEL_LENGTH = MPD_TAG_COUNT,
+	LABEL_PATH,
 	LABEL_BITRATE,
+	LABEL_FORMAT,
+	LABEL_POSITION,
 };
 
 static const char *const tag_labels[] = {
@@ -44,6 +47,7 @@ static const char *const tag_labels[] = {
 	[MPD_TAG_TITLE] = N_("Title"),
 	[MPD_TAG_ALBUM] = N_("Album"),
 	[LABEL_LENGTH] = N_("Length"),
+	[LABEL_POSITION] = N_("Position"),
 	[MPD_TAG_COMPOSER] = N_("Composer"),
 	[MPD_TAG_NAME] = N_("Name"),
 	[MPD_TAG_DISC] = N_("Disc"),
@@ -51,7 +55,9 @@ static const char *const tag_labels[] = {
 	[MPD_TAG_DATE] = N_("Date"),
 	[MPD_TAG_GENRE] = N_("Genre"),
 	[MPD_TAG_COMMENT] = N_("Comment"),
+	[LABEL_PATH] = N_("Path"),
 	[LABEL_BITRATE] = N_("Bitrate"),
+	[LABEL_FORMAT] = N_("Format"),
 };
 
 static unsigned max_tag_label_width;
@@ -120,7 +126,7 @@ screen_song_repaint(void)
 }
 
 static const char *
-screen_song_list_callback(unsigned idx, G_GNUC_UNUSED void *data)
+screen_song_list_callback(unsigned idx, gcc_unused void *data)
 {
 	assert(idx < current.lines->len);
 
@@ -173,7 +179,7 @@ screen_song_resize(int cols, int rows)
 }
 
 static const char *
-screen_song_title(G_GNUC_UNUSED char *str, G_GNUC_UNUSED size_t size)
+screen_song_title(gcc_unused char *str, gcc_unused size_t size)
 {
 	return _("Song viewer");
 }
@@ -189,12 +195,7 @@ screen_song_paint(void)
 static void
 screen_song_append(const char *label, const char *value, unsigned label_col)
 {
-	unsigned label_width = locale_width(label) + 2;
-	int value_col, label_size;
-	gchar *entry, *entry_iter;
-	const gchar *value_iter;
-	char *p, *q;
-	unsigned width;
+	const unsigned label_width = locale_width(label) + 2;
 
 	assert(label != NULL);
 	assert(value != NULL);
@@ -202,13 +203,13 @@ screen_song_append(const char *label, const char *value, unsigned label_col)
 
 	/* +2 for ': ' */
 	label_col += 2;
-	value_col = lw->cols - label_col;
+	const int value_col = lw->cols - label_col;
 	/* calculate the number of required linebreaks */
-	value_iter = value;
-	label_size = strlen(label) + label_col;
+	const gchar *value_iter = value;
+	const int label_size = strlen(label) + label_col;
 
 	while (*value_iter != 0) {
-		entry = g_malloc(label_size);
+		char *entry = g_malloc(label_size), *entry_iter;
 		if (value_iter == value) {
 			entry_iter = entry + g_sprintf(entry, "%s: ", label);
 			/* fill the label column with whitespaces */
@@ -223,8 +224,8 @@ screen_song_append(const char *label, const char *value, unsigned label_col)
 		/* skip whitespaces */
 		while (g_ascii_isspace(*value_iter)) ++value_iter;
 
-		p = g_strdup(value_iter);
-		width = utf8_cut_width(p, value_col);
+		char *p = g_strdup(value_iter);
+		unsigned width = utf8_cut_width(p, value_col);
 		if (width == 0)
 			/* not enough room for anything - bail out */
 			break;
@@ -233,7 +234,7 @@ screen_song_append(const char *label, const char *value, unsigned label_col)
 
 		value_iter += strlen(p);
 		p = replace_utf8_to_locale(p);
-		q = g_strconcat(entry, p, NULL);
+		char *q = g_strconcat(entry, p, NULL);
 		g_free(entry);
 		g_free(p);
 
@@ -256,10 +257,15 @@ screen_song_append_tag(const struct mpd_song *song, enum mpd_tag_type tag)
 }
 
 static void
-screen_song_add_song(const struct mpd_song *song, const struct mpdclient *c)
+screen_song_add_song(const struct mpd_song *song)
 {
 	assert(song != NULL);
 
+	char songpos[16];
+	g_snprintf(songpos, sizeof(songpos), "%d", mpd_song_get_pos(song) + 1);
+	screen_song_append(_(tag_labels[LABEL_POSITION]), songpos,
+			   max_tag_label_width);
+
 	screen_song_append_tag(song, MPD_TAG_ARTIST);
 	screen_song_append_tag(song, MPD_TAG_TITLE);
 	screen_song_append_tag(song, MPD_TAG_ALBUM);
@@ -269,7 +275,32 @@ screen_song_add_song(const struct mpd_song *song, const struct mpdclient *c)
 		char length[16];
 		format_duration_short(length, sizeof(length),
 				      mpd_song_get_duration(song));
-		screen_song_append(_(tag_labels[LABEL_LENGTH]), length,
+
+		const char *value = length;
+
+		char buffer[64];
+
+		if (mpd_song_get_end(song) > 0) {
+			char start[16], end[16];
+			format_duration_short(start, sizeof(start),
+					      mpd_song_get_start(song));
+			format_duration_short(end, sizeof(end),
+					      mpd_song_get_end(song));
+
+			snprintf(buffer, sizeof(buffer), "%s [%s-%s]\n",
+				 length, start, end);
+			value = buffer;
+		} else if (mpd_song_get_start(song) > 0) {
+			char start[16];
+			format_duration_short(start, sizeof(start),
+					      mpd_song_get_start(song));
+
+			snprintf(buffer, sizeof(buffer), "%s [%s-]\n",
+				 length, start);
+			value = buffer;
+		}
+
+		screen_song_append(_(tag_labels[LABEL_LENGTH]), value,
 				   max_tag_label_width);
 	}
 
@@ -281,16 +312,8 @@ screen_song_add_song(const struct mpd_song *song, const struct mpdclient *c)
 	screen_song_append_tag(song, MPD_TAG_GENRE);
 	screen_song_append_tag(song, MPD_TAG_COMMENT);
 
-	screen_song_append(_("Path"), mpd_song_get_uri(song),
+	screen_song_append(_(tag_labels[LABEL_PATH]), mpd_song_get_uri(song),
 			   max_tag_label_width);
-	if (mpdclient_is_playing(c) && c->song != NULL &&
-	    strcmp(mpd_song_get_uri(c->song), mpd_song_get_uri(song)) == 0) {
-		char buf[16];
-		g_snprintf(buf, sizeof(buf), _("%d kbps"),
-			   mpd_status_get_kbit_rate(c->status));
-		screen_song_append(_(tag_labels[LABEL_BITRATE]), buf,
-				   max_tag_label_width);
-	}
 }
 
 static void
@@ -303,15 +326,13 @@ screen_song_append_stats(enum stats_label label, const char *value)
 static bool
 screen_song_add_stats(struct mpd_connection *connection)
 {
-	char buf[64];
-	GDate *date;
-	struct mpd_stats *mpd_stats;
-
-	mpd_stats = mpd_run_stats(connection);
+	struct mpd_stats *mpd_stats = mpd_run_stats(connection);
 	if (mpd_stats == NULL)
 		return false;
 
 	g_ptr_array_add(current.lines, g_strdup(_("MPD statistics")) );
+
+	char buf[64];
 	g_snprintf(buf, sizeof(buf), "%d",
 		   mpd_stats_get_number_of_artists(mpd_stats));
 	screen_song_append_stats(STATS_ARTISTS, buf);
@@ -334,7 +355,7 @@ screen_song_add_stats(struct mpd_connection *connection)
 			     mpd_stats_get_uptime(mpd_stats));
 	screen_song_append_stats(STATS_UPTIME, buf);
 
-	date = g_date_new();
+	GDate *date = g_date_new();
 	g_date_set_time_t(date, mpd_stats_get_db_update_time(mpd_stats));
 	g_date_strftime(buf, sizeof(buf), "%x", date);
 	screen_song_append_stats(STATS_DBUPTIME, buf);
@@ -347,8 +368,6 @@ screen_song_add_stats(struct mpd_connection *connection)
 static void
 screen_song_update(struct mpdclient *c)
 {
-	struct mpd_connection *connection;
-
 	/* Clear all lines */
 	for (guint i = 0; i < current.lines->len; ++i)
 		g_free(g_ptr_array_index(current.lines, i));
@@ -367,7 +386,7 @@ screen_song_update(struct mpdclient *c)
 				mpd_song_get_uri(c->song)) != 0 ||
 			 !mpdclient_is_playing(c))) {
 		g_ptr_array_add(current.lines, g_strdup(_("Selected song")) );
-		screen_song_add_song(current.selected_song, c);
+		screen_song_add_song(current.selected_song);
 		g_ptr_array_add(current.lines, g_strdup("\0"));
 	}
 
@@ -377,12 +396,32 @@ screen_song_update(struct mpdclient *c)
 		}
 		current.played_song = mpd_song_dup(c->song);
 		g_ptr_array_add(current.lines, g_strdup(_("Currently playing song")));
-		screen_song_add_song(current.played_song, c);
+		screen_song_add_song(current.played_song);
+
+		if (mpd_status_get_kbit_rate(c->status) > 0) {
+			char buf[16];
+			g_snprintf(buf, sizeof(buf), _("%d kbps"),
+				   mpd_status_get_kbit_rate(c->status));
+			screen_song_append(_(tag_labels[LABEL_BITRATE]), buf,
+					   max_tag_label_width);
+		}
+
+		const struct mpd_audio_format *format =
+			mpd_status_get_audio_format(c->status);
+		if (format) {
+			char buf[32];
+			g_snprintf(buf, sizeof(buf), _("%u:%u:%u"),
+				   format->sample_rate, format->bits,
+				   format->channels);
+			screen_song_append(_(tag_labels[LABEL_FORMAT]), buf,
+					   max_tag_label_width);
+		}
+
 		g_ptr_array_add(current.lines, g_strdup("\0"));
 	}
 
 	/* Add some statistics about mpd */
-	connection = mpdclient_get_connection(c);
+	struct mpd_connection *connection = mpdclient_get_connection(c);
 	if (connection != NULL && !screen_song_add_stats(connection))
 		mpdclient_handle_error(c);
 
