@@ -1,21 +1,21 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
-
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
 #ifndef SCREEN_TEXT_H
 #define SCREEN_TEXT_H
@@ -66,7 +66,14 @@ screen_text_is_empty(const struct screen_text *text)
 }
 
 void
-screen_text_set(struct screen_text *text, const GString *str);
+screen_text_append(struct screen_text *text, const char *str);
+
+static inline void
+screen_text_set(struct screen_text *text, const char *str)
+{
+	screen_text_clear(text);
+	screen_text_append(text, str);
+}
 
 const char *
 screen_text_list_callback(unsigned idx, void *data);
